Documentation
¶
Index ¶
Constants ¶
const ( // EntryIDStringFormat is the format used for Sprintf function to create the ID for database entry EntryIDStringFormat = "%v_%s" // EntryIDDateFormat is the date format used in the ID EntryIDDateFormat = "2006-01-02" // EntryIDNameReplaceOld is the string which is to be replaced by EntryIDNameReplaceNew EntryIDNameReplaceOld = " " // EntryIDNameReplaceNew is the string which replaces EntryIDNameReplaceOld EntryIDNameReplaceNew = "" // DBCallNoReturn is used when call to database times out DBCallNoReturn = "Call to DB did not return" )
Variables ¶
This section is empty.
Functions ¶
Types ¶
type Task ¶
type Task struct {
// contains filtered or unexported fields
}
Task struct represents a running application.
Click to show internal directories.
Click to hide internal directories.